@@ -9,7 +9,7 @@
 #
 package Config::Model::AnyThing;
 {
-  $Config::Model::AnyThing::VERSION = '2.006';
+  $Config::Model::AnyThing::VERSION = '2.007';
 }
 
 use Any::Moose ;
@@ -20,6 +20,7 @@ use Carp;
 use Log::Log4perl qw(get_logger :levels);
 
 my $logger = get_logger("Anything") ;
+my $change_logger = get_logger("Anything::Change") ;
 
 has element_name => ( is => 'ro', isa => 'Str') ;
 has parent => (is => 'ro', isa => 'Config::Model::Node' , weak_ref => 1);
@@ -62,6 +63,8 @@ has location => (is => 'ro', isa => 'Str' , builder => '_location', lazy => 1);
 sub notify_change {	
     my $self = shift ;
 
+    $change_logger->debug("called for  ",$self->name) if $change_logger->is_debug ;
+
     $self->container->notify_change(
 	needs_write => 1 , # may be overridden by caller
 	@_, 
@@ -561,7 +564,7 @@ Config::Model::AnyThing - Base class for configuration tree item
 
 =head1 VERSION
 
-version 2.006
+version 2.007
 
 =head1 SYNOPSIS
 
