@@ -9,7 +9,7 @@
 #
 package Config::Model::Instance;
 {
-  $Config::Model::Instance::VERSION = '2.006';
+  $Config::Model::Instance::VERSION = '2.007';
 }
 #use Scalar::Util qw(weaken) ;
 
@@ -35,6 +35,7 @@ use warnings::register ;
 use Carp qw/carp croak confess cluck/;
 
 my $logger = get_logger("Instance") ;
+my $change_logger = get_logger("Anything::Change") ;
 
 has [qw/root_class_name/] => (is => 'ro', isa => 'Str', required => 1) ;
 
@@ -298,6 +299,7 @@ sub write_root_dir {
 # FIXME: record changes to implement undo/redo ?
 sub notify_change {
     my $self = shift ;
+    $change_logger->debug("called for  instance ",$self->name) if $change_logger->is_debug ;
     $self->{needs_save} = 1;
 }
 
@@ -394,7 +396,7 @@ Config::Model::Instance - Instance of configuration tree
 
 =head1 VERSION
 
-version 2.006
+version 2.007
 
 =head1 SYNOPSIS
 
