@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2011 by Dominique Dumont, Krzysztof Tyszecki.
+# This software is Copyright (c) 2012 by Dominique Dumont, Krzysztof Tyszecki.
 #
 # This is free software, licensed under:
 #
@@ -107,13 +107,13 @@ The archive area and section for each package should be specified in the package
         'value_type' => 'uniline',
         'summary' => 'Debian policy version number this package complies to',
         'warn_unless_match' => {
-          '3\\.9\\.2' => {
-            'msg' => 'Current standards version is 3.9.2',
+          '3\\.9\\.3' => {
+            'msg' => 'Current standards version is 3.9.3',
             'fix' => '$_ = undef; # restore default value'
           }
         },
         'match' => '\\d+\\.\\d+\\.\\d+(\\.\\d+)?',
-        'default' => '3.9.2',
+        'default' => '3.9.3',
         'type' => 'leaf',
         'description' => 'This field indicates the debian policy version number this package complies to'
       },
@@ -176,7 +176,7 @@ The information is meant to be useful for a user knowledgeable in the given Vers
       {
         'compute' => {
           'use_eval' => '1',
-          'formula' => '$maintainer =~ /pkg-perl/ ? "git://git.debian.org/pkg-perl/packages/$pkgname.git" : \'\' ;',
+          'formula' => '$maintainer =~ /pkg-perl/ ? "git://git.debian.org/git/pkg-perl/packages/$pkgname.git" : \'\' ;',
           'variables' => {
             'maintainer' => '- Maintainer',
             'pkgname' => '- Source'
